%define major 4
%define soffix .so.4

Name: lua%major
Version: 4.0.1
Release: alt9

Summary: Lua is a powerful, light-weight programming language
License: BSD-like
Group: Development/Other

URL: http://www.lua.org
# http://www.lua.org/ftp/
Source: lua-%version.tar.bz2

# alternatives
%define weight 10
%set_compress_method gzip
PreReq: alternatives >= 0.2
BuildPreReq: alternatives >= 0.2

Requires: lib%name = %version-%release
Provides: lua = %version

%package -n lib%name
Summary: Lua programming language, shared libraries
Group: System/Libraries

%package -n lib%name-devel
Summary: Lua programming language, header files
Group: Development/Other
Requires: lib%name = %version-%release

%package -n lib%name-devel-static
Summary: Lua programming language, static libraries
Group: Development/Other
Requires: lib%name-devel = %version-%release

%description
Lua is a powerful, light-weight programming language designed for extending
applications.  Lua is also frequently used as a general-purpose, stand-alone
language.

This package contains lua compiler and interpreter, as well as code samples
and reference manual of the language.

%description -n lib%name
Lua is a powerful, light-weight programming language designed for extending
applications.  Lua is also frequently used as a general-purpose, stand-alone
language.

This package contains lua runtime shared libraries.

%description -n lib%name-devel
Lua is a powerful, light-weight programming language designed for extending
applications.  Lua is also frequently used as a general-purpose, stand-alone
language.

This package contains header files needed to embed Lua in C/C++ programs.

%description -n lib%name-devel-static
Lua is a powerful, light-weight programming language designed for extending
applications.  Lua is also frequently used as a general-purpose, stand-alone
language.

This package contains static libraries one may need to embed lua statically.

%prep
%setup -q -n lua-%version

%build
%def_enable Werror

: custom build
DEST=$PWD/ready
%__mkdir_p $DEST

# tweak stdio.h with -D_GNU_SOURCE to get popen(3) and pclose(3) prototypes
CFLAGS="-I$PWD/include -I$PWD/src -D_POSIX_SOURCE=1 -D_GNU_SOURCE=1 -DPOPEN=1"

: static libraries
cd ./src
gcc $CFLAGS %optflags -c *.c
ar rcu $DEST/liblua.a *.o
ranlib $DEST/liblua.a

cd ./lib
gcc $CFLAGS %optflags -c *.c
ar rcu $DEST/liblualib.a *.o
ranlib $DEST/liblualib.a

: shared libraries
cd ..
gcc $CFLAGS %optflags %optflags_shared -c *.c
gcc -shared -o $DEST/liblua%soffix -Wl,-soname=liblua%soffix *.o
%__ln_s liblua%soffix $DEST/liblua.so

cd ./lib
gcc $CFLAGS %optflags %optflags_shared -c *.c
gcc -shared -o $DEST/liblualib%soffix -Wl,-soname=liblualib%soffix *.o -lm -ldl
%__ln_s liblualib%soffix $DEST/liblualib.so

: executables
cd ../lua
gcc $CFLAGS %optflags *.c -o $DEST/lua -L$DEST -llua -llualib
cd ../luac
gcc $CFLAGS %optflags *.c -o $DEST/luac -L$DEST -llua

%install
%__mkdir_p %buildroot%_libdir %buildroot%_includedir
%__cp -a ready/*.so* ready/*.a %buildroot%_libdir
%__install -p -m644 include/*.h %buildroot%_includedir

%__install -pD -m755 ready/lua %buildroot%_bindir/lua%major
%__install -pD -m755 ready/luac %buildroot%_bindir/luac%major
%__install -pD -m644 doc/lua.1 %buildroot%_man1dir/lua%major.1
%__install -pD -m644 doc/luac.1 %buildroot%_man1dir/luac%major.1

%define pkgdocdir %_docdir/lua-%version
%__mkdir_p %buildroot%pkgdocdir/{html,etc,test}
%__install -p -m644 COPYRIGHT HISTORY README* %buildroot%pkgdocdir
%__install -p -m644 doc/*.html doc/*.gif %buildroot%pkgdocdir/html
%__install -p -m644 etc/*.* etc/README %buildroot%pkgdocdir/etc
%__install -p -m644 test/*.lua test/README %buildroot%pkgdocdir/test

%__mkdir_p %buildroot%_altdir
%__cat <<__EOF__ >%buildroot%_altdir/%name
%_bindir/lua		%_bindir/%name			%weight
%_bindir/luac		%_man1dir/luac%major		%_bindir/%name
%_man1dir/lua.1.gz	%_man1dir/%name.1.gz		%_bindir/%name
%_man1dir/luac.1.gz	%_man1dir/luac%major.1.gz	%_bindir/%name
__EOF__

%post
%register_alternatives %name

%preun
%unregister_alternatives %name

%post -n lib%name -p %post_ldconfig
%postun -n lib%name -p %postun_ldconfig

%files
%_altdir/*
%_bindir/lua*
%_man1dir/*.*
%dir %pkgdocdir
%pkgdocdir/html
%pkgdocdir/etc
%pkgdocdir/test

%files -n lib%name
%_libdir/liblua%soffix
%_libdir/liblualib%soffix
%dir %pkgdocdir
%pkgdocdir/COPYRIGHT
%pkgdocdir/HISTORY
%pkgdocdir/README*

%files -n lib%name-devel
%_includedir/*.h
%_libdir/liblua.so
%_libdir/liblualib.so

%files -n lib%name-devel-static
%_libdir/liblua.a
%_libdir/liblualib.a

%changelog
* Mon May 09 2005 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt9
- upgraded to new alternatives format
- removed old dependencies
- reworked specfile to be more like lua5.spec

* Mon Feb 23 2004 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt8.2
- %_docdir/%name-%version -> %_docdir/lua-%version
- fixed luac symilnk (alternatives)

* Mon Feb 02 2004 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt8.1
- fixed %_docdir/%name-%version ownership

* Fri Jan 30 2004 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt8
- fixed _customdocdir misusage
- Werror mode enabled

* Sun Aug 24 2003 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt7
- moved lua4 (weight=10) and lua5 (weight=20) packages under alternatives control

* Fri Jun 20 2003 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt6
- new package layout: lua4, liblua4, liblua4-devel, liblua4-devel-static
- abandon makefiles, custom build with direct commands
- removed loadlib stuff (lua5 feature)
- popen feature enabled
- soname changed: liblua.so.4.0 -> liblua.so.4

* Thu Dec 26 2002 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt5
- corrected s/-lc/-lc -lm -ldl/ for liblualib.so in alt-soname patch
- shared optimization flags

* Tue Dec 24 2002 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt4
- error in previous build: *.so files are binary copy of *.so.* files,
  not symlinks; fixed
- really shared build (s/ld -shared/ld -shared -lc/ in alt-soname patch)
- post and postun sections added (ldconfig)

* Fri Dec 20 2002 Alexey Tourbin <at@altlinux.ru> 4.0.1-alt3
- shared build; alt-soname patch; lua-devel-static subpackage
- reference manual and code samples included in lua-devel package
- additional features from XTG Systems (loadlib files) and
  PLD Team (pld-loadlib-require patch)
- buildreq applied (none)

* Mon Oct 28 2002 Konstantin Volckov <goldhead@altlinux.ru> 4.0.1-alt2
- Rebuilt in new environment

* Wed Aug 28 2002 Konstantin Volckov <goldhead@altlinux.ru> 4.0.1-alt1
- First build for Sisyphus
